## Guardrails

* Add a way to see the blocked responses (trace=True)
* Add a way to self-heal and then show traces (self_heal=True, trace=True)

## Types

* Add support for TW types + json outputs

## Automation

* How to make sure only code changes are enough to generate this documentation?

## CI/CD

* How to test docs in PRs?
